@@ -20,8 +20,8 @@ typedef Eo Elm_Entry;
  */
 typedef enum
 {
-  ELM_TEXT_FORMAT_PLAIN_UTF8 = 0, /** Plain UTF8 type */
-  ELM_TEXT_FORMAT_MARKUP_UTF8 /** Markup UTF8 type */
+  ELM_TEXT_FORMAT_PLAIN_UTF8 = 0, /**< Plain UTF8 type */
+  ELM_TEXT_FORMAT_MARKUP_UTF8 /**< Markup UTF8 type */
 } Elm_Text_Format;
 
 /** Input panel (virtual keyboard) layout types. Type of input panel (virtual
@@ -32,27 +32,32 @@ typedef enum
  */
 typedef enum
 {
-  ELM_INPUT_PANEL_LAYOUT_NORMAL = 0, /** Default layout. */
-  ELM_INPUT_PANEL_LAYOUT_NUMBER, /** Number layout. */
-  ELM_INPUT_PANEL_LAYOUT_EMAIL, /** Email layout. */
-  ELM_INPUT_PANEL_LAYOUT_URL, /** URL layout. */
-  ELM_INPUT_PANEL_LAYOUT_PHONENUMBER, /** Phone Number layout. */
-  ELM_INPUT_PANEL_LAYOUT_IP, /** IP layout. */
-  ELM_INPUT_PANEL_LAYOUT_MONTH, /** Month layout. */
-  ELM_INPUT_PANEL_LAYOUT_NUMBERONLY, /** Number Only layout. */
-  ELM_INPUT_PANEL_LAYOUT_INVALID, /** Never use this. */
-  ELM_INPUT_PANEL_LAYOUT_HEX, /** Hexadecimal layout. */
-  ELM_INPUT_PANEL_LAYOUT_TERMINAL, /** Command-line terminal layout including
+  ELM_INPUT_PANEL_LAYOUT_NORMAL = 0, /**< Default layout. */
+  ELM_INPUT_PANEL_LAYOUT_NUMBER, /**< Number layout. */
+  ELM_INPUT_PANEL_LAYOUT_EMAIL, /**< Email layout. */
+  ELM_INPUT_PANEL_LAYOUT_URL, /**< URL layout. */
+  ELM_INPUT_PANEL_LAYOUT_PHONENUMBER, /**< Phone Number layout. */
+  ELM_INPUT_PANEL_LAYOUT_IP, /**< IP layout. */
+  ELM_INPUT_PANEL_LAYOUT_MONTH, /**< Month layout. */
+  ELM_INPUT_PANEL_LAYOUT_NUMBERONLY, /**< Number Only layout. */
+  ELM_INPUT_PANEL_LAYOUT_INVALID, /**< Never use this. */
+  ELM_INPUT_PANEL_LAYOUT_HEX, /**< Hexadecimal layout. */
+  ELM_INPUT_PANEL_LAYOUT_TERMINAL, /**< Command-line terminal layout including
                                     * esc, alt, ctrl key, so on (no
                                     * auto-correct, no auto-capitalization). */
-  ELM_INPUT_PANEL_LAYOUT_PASSWORD, /** Like normal, but no auto-correct, no
+  ELM_INPUT_PANEL_LAYOUT_PASSWORD, /**< Like normal, but no auto-correct, no
                                     * auto-capitalization etc. */
-  ELM_INPUT_PANEL_LAYOUT_DATETIME, /** Date and time layout
+  ELM_INPUT_PANEL_LAYOUT_DATETIME, /**< Date and time layout
                                     *
                                     * @since 1.8 */
-  ELM_INPUT_PANEL_LAYOUT_EMOTICON /** Emoticon layout
-                                   *
-                                   * @since 1.10 */
+  ELM_INPUT_PANEL_LAYOUT_EMOTICON, /**< Emoticon layout
+                                    *
+                                    * @since 1.10 */
+  ELM_INPUT_PANEL_LAYOUT_VOICE /**< Voice layout, but if the IME does not
+                                * support voice layout, then normal layout will
+                                * be shown.
+                                *
+                                * @since 1.19 */
 } Elm_Input_Panel_Layout;
 
 /**
@@ -64,8 +69,8 @@ typedef enum
  */
 typedef enum
 {
-  ELM_INPUT_PANEL_LANG_AUTOMATIC = 0, /** Automatic */
-  ELM_INPUT_PANEL_LANG_ALPHABET /** Alphabet */
+  ELM_INPUT_PANEL_LANG_AUTOMATIC = 0, /**< Automatic */
+  ELM_INPUT_PANEL_LANG_ALPHABET /**< Alphabet */
 } Elm_Input_Panel_Lang;
 
 /**
@@ -77,11 +82,11 @@ typedef enum
  */
 typedef enum
 {
-  ELM_AUTOCAPITAL_TYPE_NONE = 0, /** No auto-capitalization when typing. */
-  ELM_AUTOCAPITAL_TYPE_WORD, /** Autocapitalize each word typed. */
-  ELM_AUTOCAPITAL_TYPE_SENTENCE, /** Autocapitalize the start of each sentence.
+  ELM_AUTOCAPITAL_TYPE_NONE = 0, /**< No auto-capitalization when typing. */
+  ELM_AUTOCAPITAL_TYPE_WORD, /**< Autocapitalize each word typed. */
+  ELM_AUTOCAPITAL_TYPE_SENTENCE, /**< Autocapitalize the start of each sentence.
                                   */
-  ELM_AUTOCAPITAL_TYPE_ALLCHARACTER /** Autocapitalize all letters. */
+  ELM_AUTOCAPITAL_TYPE_ALLCHARACTER /**< Autocapitalize all letters. */
 } Elm_Autocapital_Type;
 
 /** "Return" Key types on the input panel (virtual keyboard). See also
@@ -91,16 +96,16 @@ typedef enum
  */
 typedef enum
 {
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_DEFAULT = 0, /** Default. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_DONE, /** Done. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_GO, /** Go. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_JOIN, /** Join. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_LOGIN, /** Login. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_NEXT, /** Next. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SEARCH, /** Search string or magnifier icon.
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_DEFAULT = 0, /**< Default. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_DONE, /**< Done. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_GO, /**< Go. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_JOIN, /**< Join. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_LOGIN, /**< Login. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_NEXT, /**< Next. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SEARCH, /**< Search string or magnifier icon.
                                            */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SEND, /** Send. */
-  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SIGNIN /** Sign-in
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SEND, /**< Send. */
+  ELM_INPUT_PANEL_RETURN_KEY_TYPE_SIGNIN /**< Sign-in
                                           *
                                           * @since 1.8 */
 } Elm_Input_Panel_Return_Key_Type;
@@ -113,14 +118,14 @@ typedef enum
  */
 typedef enum
 {
-  ELM_INPUT_HINT_NONE = 0, /** No active hints
+  ELM_INPUT_HINT_NONE = 0, /**< No active hints
                             *
                             * @since 1.12 */
-  ELM_INPUT_HINT_AUTO_COMPLETE = 1 /* 0 << 0 */, /** Suggest word auto
+  ELM_INPUT_HINT_AUTO_COMPLETE = 1 /* 0 >> 0 */, /**< Suggest word auto
                                                   * completion
                                                   *
                                                   * @since 1.12 */
-  ELM_INPUT_HINT_SENSITIVE_DATA = 2 /* 0 << 0 */ /** Typed text should not be
+  ELM_INPUT_HINT_SENSITIVE_DATA = 2 /* 0 >> 0 */ /**< Typed text should not be
                                                   * stored.
                                                   *
                                                   * @since 1.12 */
@@ -135,16 +140,20 @@ typedef enum
  */
 typedef enum
 {
-  ELM_CNP_MODE_MARKUP = 0, /** copy & paste text with markup tag */
-  ELM_CNP_MODE_NO_IMAGE, /** copy & paste text without item(image) tag */
-  ELM_CNP_MODE_PLAINTEXT /** copy & paste text without markup tag */
+  ELM_CNP_MODE_MARKUP = 0, /**< copy & paste text with markup tag */
+  ELM_CNP_MODE_NO_IMAGE, /**< copy & paste text without item(image) tag */
+  ELM_CNP_MODE_PLAINTEXT /**< copy & paste text without markup tag */
 } Elm_Cnp_Mode;
 
 
 #endif
+/** Elementary entry class
+ *
+ * @ingroup Elm_Entry
+ */
 #define ELM_ENTRY_CLASS elm_entry_class_get()
 
-EWAPI const Eo_Class *elm_entry_class_get(void);
+EWAPI const Efl_Class *elm_entry_class_get(void);
 
 /**
  * @brief Enable or disable scrolling in entry
@@ -174,8 +183,8 @@ EOAPI Eina_Bool elm_obj_entry_scrollable_get(const Eo *obj);
  * explicit Mouse Up event. It doesn't request to show the input panel even
  * though it has focus.
  *
- * @param[in] ondemand If true, the input panel will be shown in case of only
- * Mouse up event. (Focus event will be ignored.)
+ * @param[in] ondemand If @c true, the input panel will be shown in case of
+ * only Mouse up event. (Focus event will be ignored.)
  *
  * @since 1.9
  *
@@ -187,7 +196,7 @@ EOAPI void elm_obj_entry_input_panel_show_on_demand_set(Eo *obj, Eina_Bool ondem
  * @brief Get the attribute to show the input panel in case of only an user's
  * explicit Mouse Up event.
  *
- * @return If true, the input panel will be shown in case of only Mouse up
+ * @return If @c true, the input panel will be shown in case of only Mouse up
  * event. (Focus event will be ignored.)
  *
  * @since 1.9
@@ -269,7 +278,7 @@ EOAPI void elm_obj_entry_file_text_format_set(Eo *obj, Elm_Text_Format format);
  *
  * This API can be used if you want to show the alphabet keyboard mode.
  *
- * @param[in] lang language to be set to the input panel.
+ * @param[in] lang Language to be set to the input panel.
  *
  * @ingroup Elm_Entry
  */
@@ -278,7 +287,7 @@ EOAPI void elm_obj_entry_input_panel_language_set(Eo *obj, Elm_Input_Panel_Lang
 /**
  * @brief Get the language mode of the input panel.
  *
- * @return language to be set to the input panel.
+ * @return Language to be set to the input panel.
  *
  * @ingroup Elm_Entry
  */
@@ -305,7 +314,7 @@ EOAPI Eina_Bool elm_obj_entry_selection_handler_disabled_get(const Eo *obj);
 /**
  * @brief Set the input panel layout variation of the entry
  *
- * @param[in] variation layout variation type.
+ * @param[in] variation Layout variation type.
  *
  * @since 1.8
  *
@@ -316,7 +325,7 @@ EOAPI void elm_obj_entry_input_panel_layout_variation_set(Eo *obj, int variation
 /**
  * @brief Get the input panel layout variation of the entry
  *
- * @return layout variation type.
+ * @return Layout variation type.
  *
  * @since 1.8
  *
@@ -405,7 +414,7 @@ EOAPI const char *elm_obj_entry_anchor_hover_style_get(const Eo *obj);
  * pressing enter will break the text into a different line without generating
  * any events.
  *
- * @param[in] single_line If true, the text in the entry will be on a single
+ * @param[in] single_line If @c true, the text in the entry will be on a single
  * line.
  *
  * @ingroup Elm_Entry
@@ -415,7 +424,7 @@ EOAPI void elm_obj_entry_single_line_set(Eo *obj, Eina_Bool single_line);
 /**
  * @brief Get whether the entry is set to be single line.
  *
- * @return If true, the text in the entry will be on a single line.
+ * @return If @c true, the text in the entry will be on a single line.
  *
  * @ingroup Elm_Entry
  */
@@ -427,7 +436,7 @@ EOAPI Eina_Bool elm_obj_entry_single_line_get(const Eo *obj);
  * In password mode, entries are implicitly single line and the display of any
  * text in them is replaced with asterisks (*).
  *
- * @param[in] password If true, password mode is enabled.
+ * @param[in] password If @c true, password mode is enabled.
  *
  * @ingroup Elm_Entry
  */
@@ -436,7 +445,7 @@ EOAPI void elm_obj_entry_password_set(Eo *obj, Eina_Bool password);
 /**
  * @brief Get whether the entry is set to password mode.
  *
- * @return If true, password mode is enabled.
+ * @return If @c true, password mode is enabled.
  *
  * @ingroup Elm_Entry
  */
@@ -545,7 +554,7 @@ EOAPI Elm_Input_Hints elm_obj_entry_input_hint_get(const Eo *obj);
 /**
  * @brief Set the input panel layout of the entry.
  *
- * @param[in] layout layout type.
+ * @param[in] layout Layout type.
  *
  * @ingroup Elm_Entry
  */
@@ -554,7 +563,7 @@ EOAPI void elm_obj_entry_input_panel_layout_set(Eo *obj, Elm_Input_Panel_Layout
 /**
  * @brief Get the input panel layout of the entry.
  *
- * @return layout type.
+ * @return Layout type.
  *
  * @ingroup Elm_Entry
  */
@@ -566,6 +575,9 @@ EOAPI Elm_Input_Panel_Layout elm_obj_entry_input_panel_layout_get(const Eo *obj)
  *
  * An input panel displays the string or icon associated with this type.
  *
+ * Regardless of return key type, "activated" event will be generated when
+ * pressing return key in single line entry.
+ *
  * @param[in] return_key_type The type of "return" key on the input panel.
  *
  * @ingroup Elm_Entry
@@ -584,7 +596,7 @@ EOAPI Elm_Input_Panel_Return_Key_Type elm_obj_entry_input_panel_return_key_type_
 /**
  * @brief Sets the attribute to show the input panel automatically.
  *
- * @param[in] enabled If true, the input panel is appeared when entry is
+ * @param[in] enabled If @c true, the input panel is appeared when entry is
  * clicked or has a focus.
  *
  * @ingroup Elm_Entry
@@ -594,8 +606,8 @@ EOAPI void elm_obj_entry_input_panel_enabled_set(Eo *obj, Eina_Bool enabled);
 /**
  * @brief Get the attribute to show the input panel automatically.
  *
- * @return If true, the input panel is appeared when entry is clicked or has a
- * focus.
+ * @return If @c true, the input panel is appeared when entry is clicked or has
+ * a focus.
  *
  * @ingroup Elm_Entry
  */
@@ -697,7 +709,7 @@ EOAPI void elm_obj_entry_select_region_get(const Eo *obj, int *start, int *end);
  * entry has no text. The return key on the input panel is automatically
  * enabled when the entry has text. The default value is @c false.
  *
- * @param[in] enabled If @c enabled is true, the return key is automatically
+ * @param[in] enabled If @c enabled is @c true, the return key is automatically
  * disabled when the entry has no text.
  *
  * @ingroup Elm_Entry
@@ -708,7 +720,7 @@ EOAPI void elm_obj_entry_input_panel_return_key_autoenabled_set(Eo *obj, Eina_Bo
  * @brief Sets the visibility of the end widget of the entry, set by @ref
  * elm_object_part_content_set(ent, "end", content).
  *
- * @param[in] setting true if the object should be displayed, false if not.
+ * @param[in] setting @c true if the object should be displayed, false if not.
  *
  * @ingroup Elm_Entry
  */
@@ -755,6 +767,8 @@ EOAPI void elm_obj_entry_cursor_end_set(Eo *obj);
  * internal textblock object). This applies to all cursors returned from
  * textblock calls, and all the other derivative values.
  *
+ * @return Textblock object
+ *
  * @ingroup Elm_Entry
  */
 EOAPI Efl_Canvas_Object *elm_obj_entry_textblock_get(const Eo *obj);
@@ -765,14 +779,16 @@ EOAPI Efl_Canvas_Object *elm_obj_entry_textblock_get(const Eo *obj);
  * It's useful if you want to draw something on the cursor (or where it is), or
  * for example in the case of scrolled entry where you want to show the cursor.
  *
- * @param[out] x returned geometry.
- * @param[out] y returned geometry.
- * @param[out] w returned geometry.
- * @param[out] h returned geometry.
+ * @param[out] x X coordinate
+ * @param[out] y Y coordinate
+ * @param[out] w Width
+ * @param[out] h Height
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
-EOAPI Eina_Bool elm_obj_entry_cursor_geometry_get(const Eo *obj, Evas_Coord *x, Evas_Coord *y, Evas_Coord *w, Evas_Coord *h);
+EOAPI Eina_Bool elm_obj_entry_cursor_geometry_get(const Eo *obj, int *x, int *y, int *w, int *h);
 
 /**
  * @brief Returns the input method context of the entry.
@@ -782,6 +798,8 @@ EOAPI Eina_Bool elm_obj_entry_cursor_geometry_get(const Eo *obj, Evas_Coord *x,
  * IMPORTANT: Many functions may change (i.e delete and create a new one) the
  * internal input method context. Do NOT cache the returned object.
  *
+ * @return Input method context
+ *
  * @ingroup Elm_Entry
  */
 EOAPI void *elm_obj_entry_imf_context_get(const Eo *obj);
@@ -794,6 +812,8 @@ EOAPI void *elm_obj_entry_imf_context_get(const Eo *obj);
  * invisible one, such as bold begin or end tag. This function returns whether
  * any format node exists at the current cursor position.
  *
+ * @return @c true if format node exists, @c false otherwise
+ *
  * @ingroup Elm_Entry
  */
 EOAPI Eina_Bool elm_obj_entry_cursor_is_format_get(const Eo *obj);
@@ -806,9 +826,11 @@ EOAPI Eina_Bool elm_obj_entry_cursor_is_format_get(const Eo *obj);
  * not be part of the return value. You must free the string when done with
  * @ref free.
  *
+ * @return Character
+ *
  * @ingroup Elm_Entry
  */
-EOAPI char *elm_obj_entry_cursor_content_get(const Eo *obj);
+EOAPI char *elm_obj_entry_cursor_content_get(const Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Get any selected text within the entry.
@@ -821,11 +843,16 @@ EOAPI char *elm_obj_entry_cursor_content_get(const Eo *obj);
  * modified in any way. If the @c entry object is deleted or its contents are
  * changed, the returned pointer should be considered invalid.
  *
+ * @return Selected string
+ *
  * @ingroup Elm_Entry
  */
 EOAPI const char *elm_obj_entry_selection_get(const Eo *obj);
 
-/** Get if the current cursor position holds a visible format node.
+/**
+ * @brief Get if the current cursor position holds a visible format node.
+ *
+ * @return @c true if position has a visible format, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -853,7 +880,10 @@ EOAPI void elm_obj_entry_select_allow_set(Eo *obj, Eina_Bool allow);
  */
 EOAPI Eina_Bool elm_obj_entry_select_allow_get(const Eo *obj);
 
-/** This moves the cursor one place to the left within the entry.
+/**
+ * @brief This moves the cursor one place to the left within the entry.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -931,7 +961,10 @@ EOAPI void elm_obj_entry_anchor_hover_end(Eo *obj);
  */
 EOAPI void elm_obj_entry_cursor_selection_begin(Eo *obj);
 
-/** This moves the cursor one line down within the entry.
+/**
+ * @brief This moves the cursor one line down within the entry.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -983,6 +1016,8 @@ EOAPI void elm_obj_entry_item_provider_remove(Eo *obj, Elm_Entry_Item_Provider_C
  *
  * See also @ref elm_obj_entry_text_style_user_push.
  *
+ * @return Style
+ *
  * @since 1.7
  *
  * @ingroup Elm_Entry
@@ -999,7 +1034,10 @@ EOAPI const char *elm_obj_entry_text_style_user_peek(const Eo *obj);
  */
 EOAPI void elm_obj_entry_context_menu_clear(Eo *obj);
 
-/** This moves the cursor one line up within the entry.
+/**
+ * @brief This moves the cursor one line up within the entry.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -1056,7 +1094,10 @@ EOAPI void elm_obj_entry_input_panel_imdata_get(const Eo *obj, void *data, int *
  */
 EOAPI void elm_obj_entry_selection_paste(Eo *obj);
 
-/** This moves the cursor one place to the right within the entry.
+/**
+ * @brief This moves the cursor one place to the right within the entry.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Entry
  */
@@ -1106,6 +1147,8 @@ EOAPI void elm_obj_entry_selection_cut(Eo *obj);
  * for which no provider finds anything, and no text is displayed, this
  * function still returns @c false.
  *
+ * @return @c true if empty, @c false otherwise
+ *
  * @ingroup Elm_Entry
  */
 EOAPI Eina_Bool elm_obj_entry_is_empty(const Eo *obj);
@@ -1210,130 +1253,183 @@ EOAPI void elm_obj_entry_context_menu_item_add(Eo *obj, const char *label, const
  */
 EOAPI void elm_obj_entry_markup_filter_prepend(Eo *obj, Elm_Entry_Filter_Cb func, void *data);
 
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ACTIVATED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CHANGED_USER;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_VALIDATE;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CONTEXT_OPEN;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ANCHOR_CLICKED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_REJECTED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_MAXLENGTH_REACHED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_PREEDIT_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_PRESS;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_REDO_REQUEST;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_UNDO_REQUEST;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_TEXT_SET_DONE;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ABORTED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ANCHOR_DOWN;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ANCHOR_HOVER_OPENED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ANCHOR_IN;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ANCHOR_OUT;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_ANCHOR_UP;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CURSOR_CHANGED;
-EOAPI extern const Eo_Event_Description _ELM_ENTRY_EVENT_CURSOR_CHANGED_MANUAL;
-
 /**
- * No description
+ * @brief Sets the prediction hint to use an intelligent reply suggestion
+ * service.
+ *
+ * @param[in] prediction_hint The prediction hint text.
+ *
+ * @since 1.20
+ *
+ * @ingroup Elm_Entry
+ */
+EOAPI void elm_obj_entry_prediction_hint_set(Eo *obj, const char *prediction_hint);
+
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_ACTIVATED;
+
+/** Called when entry got activated
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_ACTIVATED (&(_ELM_ENTRY_EVENT_ACTIVATED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_CHANGED;
+
+/** Called when entry changed
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_CHANGED (&(_ELM_ENTRY_EVENT_CHANGED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_CHANGED_USER;
+
+/** Called when the object changed due to user interaction
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_CHANGED_USER (&(_ELM_ENTRY_EVENT_CHANGED_USER))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_VALIDATE;
+
+/** Called when validating
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_VALIDATE (&(_ELM_ENTRY_EVENT_VALIDATE))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_CONTEXT_OPEN;
+
+/** Called when context menu was opened
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_CONTEXT_OPEN (&(_ELM_ENTRY_EVENT_CONTEXT_OPEN))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_ANCHOR_CLICKED;
+
+/** Called when anchor was clicked
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_ANCHOR_CLICKED (&(_ELM_ENTRY_EVENT_ANCHOR_CLICKED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_REJECTED;
+
+/** Called when entry was rejected
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_REJECTED (&(_ELM_ENTRY_EVENT_REJECTED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_MAXLENGTH_REACHED;
+
+/** Called when maximum entry length has been reached
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_MAXLENGTH_REACHED (&(_ELM_ENTRY_EVENT_MAXLENGTH_REACHED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_PREEDIT_CHANGED;
+
+/** Called when entry preedit changed
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_PREEDIT_CHANGED (&(_ELM_ENTRY_EVENT_PREEDIT_CHANGED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_PRESS;
+
+/** Called when entry pressed
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_PRESS (&(_ELM_ENTRY_EVENT_PRESS))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_REDO_REQUEST;
+
+/** Called when redo was requested
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_REDO_REQUEST (&(_ELM_ENTRY_EVENT_REDO_REQUEST))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_UNDO_REQUEST;
+
+/** Called when undo was requested
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_UNDO_REQUEST (&(_ELM_ENTRY_EVENT_UNDO_REQUEST))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_TEXT_SET_DONE;
+
+/** Called when text set finished
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_TEXT_SET_DONE (&(_ELM_ENTRY_EVENT_TEXT_SET_DONE))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_ABORTED;
+
+/** Called when entry was aborted
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_ABORTED (&(_ELM_ENTRY_EVENT_ABORTED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_ANCHOR_DOWN;
+
+/** Called on anchor down
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_ANCHOR_DOWN (&(_ELM_ENTRY_EVENT_ANCHOR_DOWN))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_ANCHOR_HOVER_OPENED;
+
+/** Called when hover opened
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_ANCHOR_HOVER_OPENED (&(_ELM_ENTRY_EVENT_ANCHOR_HOVER_OPENED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_ANCHOR_IN;
+
+/** Called on anchor in
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_ANCHOR_IN (&(_ELM_ENTRY_EVENT_ANCHOR_IN))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_ANCHOR_OUT;
+
+/** Called on anchor out
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_ANCHOR_OUT (&(_ELM_ENTRY_EVENT_ANCHOR_OUT))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_ANCHOR_UP;
+
+/** called on anchor up
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_ANCHOR_UP (&(_ELM_ENTRY_EVENT_ANCHOR_UP))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_CURSOR_CHANGED;
+
+/** Called on cursor changed
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_CURSOR_CHANGED (&(_ELM_ENTRY_EVENT_CURSOR_CHANGED))
 
-/**
- * No description
+EWAPI extern const Efl_Event_Description _ELM_ENTRY_EVENT_CURSOR_CHANGED_MANUAL;
+
+/** Called on manual cursor change
+ *
+ * @ingroup Elm_Entry
  */
 #define ELM_ENTRY_EVENT_CURSOR_CHANGED_MANUAL (&(_ELM_ENTRY_EVENT_CURSOR_CHANGED_MANUAL))
 
